Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunCmd ¶
RunCmd executes a system command without capturing its output.
The function takes the command to be run as the first argument followed by its arguments. For example, to run "ls -l", call RunCmd("ls", "-l").
Returns an error if the command exits with a non-zero status.
func RunCmdCombinedOutput ¶
RunCmdCombinedOutput executes a system command and returns its combined standard output and standard error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.