Documentation
¶
Overview ¶
Package git provides utilities to interact with git repositories.
This package is primarily designed to clone and pull updates from git repositories, specifically with support for optional credentials in the form of username and password from environment variables.
Author: zakaria.elbouwab zcubbs https://github.com/zcubbs
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloneRepository ¶ added in v0.1.15
CloneRepository clones a Git repository into a given directory with optional authentication.
func FileHasChanges ¶
func GetLatestCommit ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.